summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/forms/kexiformview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/forms/kexiformview.cpp')
-rw-r--r--kexi/plugins/forms/kexiformview.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/kexi/plugins/forms/kexiformview.cpp b/kexi/plugins/forms/kexiformview.cpp
index c6d689f7..01ec080f 100644
--- a/kexi/plugins/forms/kexiformview.cpp
+++ b/kexi/plugins/forms/kexiformview.cpp
@@ -90,7 +90,7 @@ KexiFormView::KexiFormView(KexiMainWindow *mainWin, TQWidget *parent,
if (viewMode()==Kexi::DataViewMode) {
m_scrollView->recordNavigator()->setRecordHandler( m_scrollView );
- m_scrollView->viewport()->setPaletteBackgroundColor(m_dbform->palette().active().background());
+ m_scrollView->viewport()->setPaletteBackgroundColor(m_dbform->tqpalette().active().background());
//moved to formmanager connect(formPart()->manager(), TQT_SIGNAL(noFormSelected()), TQT_SLOT(slotNoFormSelected()));
}
else
@@ -345,12 +345,12 @@ void KexiFormView::updateValuesForSubproperties()
kexipluginsdbg << "KexiFormView::loadForm(): delayed setting of the subproperty: widget="
<< it.current()->widget()->name() << " prop=" << subpropIt.key() << " val=" << subpropIt.data() << endl;
- const int count = subwidget->metaObject()->findProperty(subpropIt.key().latin1(), true);
- const TQMetaProperty *meta = count!=-1 ? subwidget->metaObject()->property(count, true) : 0;
+ const int count = subwidget->tqmetaObject()->findProperty(subpropIt.key().latin1(), true);
+ const TQMetaProperty *meta = count!=-1 ? subwidget->tqmetaObject()->property(count, true) : 0;
if (meta) {
// Special case: the property value of type enum (set) but is saved as a string list,
// not as int, so we need to translate it to int. It's been created as such
- // by FormIO::readPropertyValue(). Example: "alignment" property.
+ // by FormIO::readPropertyValue(). Example: "tqalignment" property.
if (meta->isSetType() && subpropIt.data().type()==TQVariant::StringList) {
TQStrList keys;
const TQStringList list( subpropIt.data().toStringList() );
@@ -371,7 +371,7 @@ void KexiFormView::updateValuesForSubproperties()
static void setUnsavedBLOBIdsForDataViewMode(
TQWidget* widget, const TQMap<TQCString, KexiBLOBBuffer::Id_t>& unsavedLocalBLOBsByName)
{
- if (-1 != widget->metaObject()->findProperty("pixmapId")) {
+ if (-1 != widget->tqmetaObject()->findProperty("pixmapId")) {
const KexiBLOBBuffer::Id_t blobID = unsavedLocalBLOBsByName[ widget->name() ];
if (blobID > 0)
widget->setProperty("pixmapId", (uint /* KexiBLOBBuffer::Id_t is unsafe and unsupported by TQVariant - will be fixed in TQt4*/)blobID);
@@ -525,9 +525,9 @@ KexiFormView::afterSwitchFrom(int mode)
//set focus on 1st focusable widget which has valid dataSource property set
if (!m_dbform->orderedFocusWidgets()->isEmpty()) {
-// TQWidget *www = focusWidget();
- //if (Kexi::hasParent(this, tqApp->focusWidget())) {
- KexiUtils::unsetFocusWithReason(tqApp->focusWidget(), TQFocusEvent::Tab);
+// TQWidget *www = tqfocusWidget();
+ //if (Kexi::hasParent(this, tqApp->tqfocusWidget())) {
+ KexiUtils::unsetFocusWithReason(tqApp->tqfocusWidget(), TQFocusEvent::Tab);
//}
TQPtrListIterator<TQWidget> it(*m_dbform->orderedFocusWidgets());
@@ -860,7 +860,7 @@ KexiFormView::slotWidgetSelected(KFormDesigner::Form *f, bool multiple)
setAvailable("formpart_format_raise", true);
setAvailable("formpart_format_lower", true);
- // If the widgets selected is a container, we enable layout actions
+ // If the widgets selected is a container, we enable tqlayout actions
if(!multiple)
{
KFormDesigner::ObjectTreeItem *item = f->objectTree()->lookup( f->selectedWidgets()->first()->name() );
@@ -999,14 +999,14 @@ void
KexiFormView::setFocusInternal()
{
if (viewMode() == Kexi::DataViewMode) {
- if (m_dbform->focusWidget()) {
+ if (m_dbform->tqfocusWidget()) {
//better-looking focus
if (m_setFocusInternalOnce) {
KexiUtils::setFocusWithReason(m_setFocusInternalOnce, TQFocusEvent::Other);//Tab);
m_setFocusInternalOnce = 0;
}
else {
- //ok? SET_FOCUS_USING_REASON(m_dbform->focusWidget(), TQFocusEvent::Other);//Tab);
+ //ok? SET_FOCUS_USING_REASON(m_dbform->tqfocusWidget(), TQFocusEvent::Other);//Tab);
}
return;
}
@@ -1115,7 +1115,7 @@ KexiFormView::insertAutoFields(const TQString& sourceMimeType, const TQString& s
// KFormDesigner::WidgetList* prevSelection = form()->selectedWidgets();
KFormDesigner::WidgetList widgetsToSelect;
KFormDesigner::CommandGroup *group = new KFormDesigner::CommandGroup(
- fields.count()==1 ? i18n("Insert AutoField widget") : i18n("Insert %1 AutoField widgets").arg(fields.count()),
+ fields.count()==1 ? i18n("Insert AutoField widget") : i18n("Insert %1 AutoField widgets").tqarg(fields.count()),
KFormDesigner::FormManager::self()->propertySet()
);
@@ -1173,8 +1173,8 @@ KexiFormView::insertAutoFields(const TQString& sourceMimeType, const TQString& s
// newWidget->setDataSource(column->aliasOrName());
// newWidget->setFieldTypeInternal((int)column->field->type());
// newWidget->setFieldCaptionInternal(column->captionOrAliasOrName());
- //resize again because autofield's type changed what can lead to changed sizeHint()
-// newWidget->resize(newWidget->sizeHint());
+ //resize again because autofield's type changed what can lead to changed tqsizeHint()
+// newWidget->resize(newWidget->tqsizeHint());
KFormDesigner::WidgetList list;
list.append(newWidget);
KFormDesigner::AdjustSizeCommand *adjustCommand
@@ -1191,10 +1191,10 @@ KexiFormView::insertAutoFields(const TQString& sourceMimeType, const TQString& s
}
if (widgetsToSelect.last()) {
//resize form if needed
- TQRect oldFormRect( m_dbform->geometry() );
+ TQRect oldFormRect( m_dbform->tqgeometry() );
TQRect newFormRect( oldFormRect );
- newFormRect.setWidth(TQMAX(m_dbform->width(), widgetsToSelect.last()->geometry().right()+1));
- newFormRect.setHeight(TQMAX(m_dbform->height(), widgetsToSelect.last()->geometry().bottom()+1));
+ newFormRect.setWidth(TQMAX(m_dbform->width(), widgetsToSelect.last()->tqgeometry().right()+1));
+ newFormRect.setHeight(TQMAX(m_dbform->height(), widgetsToSelect.last()->tqgeometry().bottom()+1));
if (newFormRect != oldFormRect) {
//1. resize by hand
m_dbform->setGeometry( newFormRect );
@@ -1205,8 +1205,8 @@ KexiFormView::insertAutoFields(const TQString& sourceMimeType, const TQString& s
group->addCommand(resizeFormCommand, true/*will be executed on CommandGroup::execute()*/);
}
- //remember geometry of the last inserted widget
- m_widgetGeometryForRecentInsertAutoFields = widgetsToSelect.last()->geometry();
+ //remember tqgeometry of the last inserted widget
+ m_widgetGeometryForRecentInsertAutoFields = widgetsToSelect.last()->tqgeometry();
}
//eventually, add entire command group to active form
@@ -1217,11 +1217,11 @@ KexiFormView::insertAutoFields(const TQString& sourceMimeType, const TQString& s
//enable proper REDO usage
group->resetAllowExecuteFlags();
- m_scrollView->repaint();
- m_scrollView->viewport()->repaint();
+ m_scrollView->tqrepaint();
+ m_scrollView->viewport()->tqrepaint();
m_scrollView->repaintContents();
m_scrollView->updateContents();
- m_scrollView->clipper()->repaint();
+ m_scrollView->clipper()->tqrepaint();
m_scrollView->refreshContentsSize();
//select all inserted widgets, if multiple